@@ -9,7 +9,7 @@
 ### This code was originally written to package up BitPim but has been
 ### refactored to build almost any Python program.
 ###
-### $Id: makedist.py 4278 2007-06-12 02:30:38Z djpham $
+### $Id: makedist.py 4413 2007-09-28 18:22:42Z djpham $
 
 
 # Runs on Linux, Windows and Mac
@@ -30,6 +30,7 @@ import email.Utils
 import time
 import zipfile
 import getopt
+import subprocess
 
 # i got real tired of typing these and having the lines get really long
 opj=os.path.join
@@ -98,34 +99,17 @@ def run(*args, **kwargs):
     verbose=kwargs.get("verbose", True)
     if verbose:
         print `args`
-    sl=os.spawnl
-    if sys.platform!='win32':
-        sl=os.spawnlp
-        ret=apply(sl, (os.P_WAIT,args[0])+args)
-    else:
-        # win98 was fine with above code, winxp just chokes
-        # so we call system() instead
-        str=""
-        for a in args:
-            if a.find(' ')>=0:
-                str+=' "'+a+'"'
-            else:
-                str+=" "+a
-        str=str[1:] # remove first space
-        # If you ever wanted proof how idiotic windows is, here it is
-        # if there is a value enclosed in double quotes, it is
-        # taken as the window title, even if it comes after all
-        # the switches, so i have to supply one, otherwise it mistakes
-        # the command to run as the window title
-        ret=os.system('start /b /wait "%s" %s' % (args[0], str))
+    p=subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE,
+                       universal_newlines=True)
+    _res=p.communicate()
     if verbose:
-        print "returned", ret
-    if ret!=0:
+        print "returned", p.returncode
+    if p.returncode:
         if not verbose:
             print `args`
-            print "returned", ret
-        raise Exception("The command failed")
-
+            print "returned", p.returncode
+        raise Exception("The command failed:\n%s", _res[1])
+    
 def clean():
     """Remove temporary directories created by various packaging tools"""
     if os.path.isdir("dist"):
@@ -308,16 +292,18 @@ def linuxcommonbuild(pkg, vals):
             os.makedirs(opd(p))
         open(p, "wt").write(
             """#!/bin/sh
-            exec %s "$@"\n""" % (opj(app['lib_path'], app['dest_base']),))
+            LD_LIBRARY_PATH=%s:$LD_LIBRARY_PATH exec %s "$@"\n""" % (app['lib_path'], opj(app['lib_path'], app['dest_base'])))
         os.chmod(p, 0555)
 
-    # fix wxPython shared libraries - cxfreeze doesn't bring them all in and
+    # fix python/wxPython shared libraries - cxfreeze doesn't bring them all in and
     # rpath needs to be stripped out
     copy={}
-    for so in recursiveglob(opj(opts['options']['cxfreeze']['dist_dir'], "*.so")):
+    for so in recursiveglob(opj(opts['options']['cxfreeze']['dist_dir'], "*.so"))+\
+        recursiveglob(opj(opts['options']['cxfreeze']['dist_dir'], app['dest_base'])):
         for line in os.popen("ldd "+so, "r"):
             line=line.split()
-            if line[-2].startswith("/usr/lib/wxPython-"):
+            if line[-2].startswith("/usr/lib/wxPython-") or \
+               line[-2].startswith("/usr/lib/libpython"):
                 pd=opd(so)
                 libs=copy.get(pd, [])
                 if line[2] not in libs:
@@ -411,6 +397,42 @@ def linuxdebbuild(pkg, vals):
     run(opj('debian', 'rules'), "binary")
     os.chdir(_pwd)
 
+def linuxebuildbuild(pkg, vals):
+    """Do all the steps necessary to make a gentoo tbz2 package"""
+    # Build the tree
+    opts=linuxcommonbuild(pkg, vals)
+    # Setting up the dir structure
+    distfilesdir=opj(opts['options']['cxfreeze']['dist_dir'])
+    distdir=opd(distfilesdir)
+    builddir=opj(distdir, "build")
+    os.mkdir(builddir)
+    # setting vars to pass to ebuild
+    _pwd=os.getcwd()
+    vals['FILESDIR']=os.path.abspath(distfilesdir)
+    vals['BUILDDIR']=os.path.abspath(builddir)
+    # gentoo portage dirs
+    _portage_dist_dir='/usr/portage/distfiles'
+    _portage_overlay_bitpim_dir='/usr/local/portage/app-mobilephone/bitpim'
+    _portage_packages_dir='/usr/portage/packages/All'
+    # manually "fetch" the load
+    os.chdir(distfilesdir)
+    _basename=opts['app'][0]['dest_base']
+    run('tar', 'cjf', opj(_portage_dist_dir, '%s-%s.tar.bz2'%(_basename, vals['VERSION'])),
+        '.')
+    os.chdir(_pwd)
+    # copy over and subst the ebuild file
+    _ebuildfile=opj(_portage_overlay_bitpim_dir, '%s-%s.ebuild'%(_basename, vals['VERSION']))
+    shutil.copy2(opj('packaging', 'gentoo', '%s.ebuild'%_basename), _ebuildfile)
+    dosubs(vals, _ebuildfile, _ebuildfile)
+    # and run ebuild on it
+    os.chdir(_portage_overlay_bitpim_dir)
+    run('ebuild', _ebuildfile, 'digest', 'package', 'clean')
+    os.chdir(_pwd)
+    # copy the package file (tbz2) over to dist
+    shutil.copy2(opj(_portage_packages_dir, '%s-%s.tbz2'%(_basename, vals['VERSION'])),
+         distdir)
+                     
+
 def macbuild(pkg, vals):
     """Do all the steps necessary to make a Mac dimg
     
@@ -447,7 +469,7 @@ def macbuild(pkg, vals):
                          'CFBundleGetInfoString': '%%NAME%%-%%VERSION%%',
                          'CFBundleExecutable': '%%NAME%%',
                          'CFBundleIdentifier': '%%GUID%%',
-                         'PyResourcePackages': ['lib/python2.3/lib-dynload'],
+                         'PyResourcePackages': ['lib/python2.5/lib-dynload'],
                       },
                     'prefer_ppc': 'true',
                  },
@@ -616,7 +638,7 @@ if __name__=='__main__':
     sys.excepthook=eh
 
     try:
-        _options, _args=getopt.gnu_getopt(sys.argv[1:], 'p:v:')
+        _options, _args=getopt.gnu_getopt(sys.argv[1:], 'p:v:l:')
         if _args:
             raise getopt.GetoptError('Invalid argument')
         _invalid_opt=False
@@ -625,17 +647,21 @@ if __name__=='__main__':
         _invalid_opt=True
     if _invalid_opt:
         print _error_str
-        print 'Usage: %s [-p <package module>] [-v <version>]'%sys.argv[0]
+        print 'Usage: %s [-p <package module>] [-v <version>] ' \
+              '[-l redhat|debian|gentoo]'%sys.argv[0]
         sys.exit(1)
 
     # default support script and version
     pkg="src/package.py"
     _thisversion=None
+    _platformname=None
     for _k, _v in _options:
         if _k=='-p':
             pkg=_v
         elif _k=='-v':
             _thisversion=_v
+        elif _k=='-l':
+            _platformname=_v.lower()
 
     print "Using package file",pkg
 
@@ -643,6 +669,8 @@ if __name__=='__main__':
 
     pkg=__import__(os.path.splitext(os.path.basename(pkg))[0])
 
+    if _thisversion:
+        pkg.setversion(_thisversion)
     # do a sanity check
     sanitycheck()  # ours
     if hasattr(pkg, 'sanitycheck'):
@@ -651,8 +679,6 @@ if __name__=='__main__':
         pkg.ensureofficial()
 
     vals=pkg.getvals()
-    if _thisversion:
-        vals['VERSION']=_thisversion
     print 'version', vals['VERSION']
 
     # fixup vals
@@ -670,12 +696,15 @@ if __name__=='__main__':
     if sys.platform=='win32':
         windowsbuild(pkg, vals)
     elif sys.platform.startswith('linux'):
-        import platform
-        _platformname=platform.dist()[0].lower()
+        if not _platformname:
+            import platform
+            _platformname=platform.dist()[0].lower()
         if _platformname in ('redhat', 'suse', 'mandrake'):
             linuxrpmbuild(pkg, vals)
         elif _platformname=='debian':
             linuxdebbuild(pkg, vals)
+        elif _platformname=='gentoo':
+            linuxebuildbuild(pkg, vals)
         else:
             raise Exception("Don't know what to do with "+`platform.dist()`)
     elif sys.platform=='darwin':
