@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: call_history.py 3841 2007-01-03 03:30:29Z djpham $
+### $Id: call_history.py 4374 2007-08-23 03:14:24Z djpham $
 
 """
 Code to handle Call History data storage and display.
@@ -34,6 +34,7 @@ The result dict key is 'call_history'.
 """
 
 # standard modules
+from __future__ import with_statement
 import copy
 import sha
 import time
@@ -293,29 +294,28 @@ class CallHistoryWidget(scrolled.ScrolledPanel, widgets.BitPimWidget):
             current_choice=guiwidgets.HistoricalDataDialog.Historical_Data
         else:
             current_choice=guiwidgets.HistoricalDataDialog.Current_Data
-        dlg=guiwidgets.HistoricalDataDialog(self,
-                                            current_choice=current_choice,
-                                            historical_date=self.historical_date,
-                                            historical_events=\
-                                            self._main_window.database.getchangescount(self._data_key))
-        if dlg.ShowModal()==wx.ID_OK:
-            self._main_window.OnBusyStart()
-            current_choice, self.historical_date=dlg.GetValue()
-            r={}
-            if current_choice==guiwidgets.HistoricalDataDialog.Current_Data:
-                self.read_only=False
-                msg_str='Current Data'
-                self.getfromfs(r)
-            else:
-                self.read_only=True
-                msg_str='Historical Data as of %s'%\
-                         str(wx.DateTimeFromTimeT(self.historical_date))
-                self.getfromfs(r, self.historical_date)
-            self.populate(r, True)
-            self.historical_data_label.SetLabel(msg_str)
-            self.list_widget.historical_data_label.SetLabel(msg_str)
-            self._main_window.OnBusyEnd()
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(guiwidgets.HistoricalDataDialog(self,
+                                                                       current_choice=current_choice,
+                                                                       historical_date=self.historical_date,
+                                                                       historical_events=\
+                                                                       self._main_window.database.getchangescount(self._data_key)),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                with guihelper.MWBusyWrapper(self._main_window):
+                    current_choice, self.historical_date=dlg.GetValue()
+                    r={}
+                    if current_choice==guiwidgets.HistoricalDataDialog.Current_Data:
+                        self.read_only=False
+                        msg_str='Current Data'
+                        self.getfromfs(r)
+                    else:
+                        self.read_only=True
+                        msg_str='Historical Data as of %s'%\
+                                 str(wx.DateTimeFromTimeT(self.historical_date))
+                        self.getfromfs(r, self.historical_date)
+                    self.populate(r, True)
+                    self.historical_data_label.SetLabel(msg_str)
+                    self.list_widget.historical_data_label.SetLabel(msg_str)
 
     def _publish_today_data(self):
         keys=[(x.datetime, k) for k,x in self._data.items()]
