@@ -5,11 +5,13 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: gui.py 4287 2007-06-12 02:33:21Z djpham $
+### $Id: gui.py 4407 2007-09-25 20:39:48Z djpham $
 
 """The main gui code for BitPim""" 
 
 # System modules
+from __future__ import with_statement
+import contextlib
 import thread, threading
 import Queue
 import time
@@ -23,7 +25,6 @@ import types
 import datetime
 import sha
 import codecs
-import locale
 
 # wx modules
 import wx
@@ -323,6 +324,23 @@ class _NotSafeObject:
 
 _NotSafeObject=_NotSafeObject()
 
+class Event(object):
+    """Simple Event class that supports Context Manager"""
+    def __init__(self):
+        self._event=threading.Event()
+    def __enter__(self):
+        self._event.set()
+    def __exit__(self, exc_type, exc_value, tb):
+        self._event.clear()
+    def set(self):
+        return self._event.set()
+    def clear(self):
+        return self._event.clear()
+    def isSet(self):
+        return self._event.isSet()
+    def wait(self, timeout=None):
+        return self._event.wait(timeout)
+
 EVT_CALLBACK=None
 class MainApp(wx.App):
     def __init__(self, argv, config_filename=None):
@@ -330,6 +348,8 @@ class MainApp(wx.App):
         self.SAFEMODE=False
         codecs.register(phone_media_codec.search_func)
         self._config_filename=config_filename
+        # simple Event object to flag when entering/leaving critical section
+        self.critical=Event()
         wx.App.__init__(self, redirect=False,
                         useBestVisual=not guihelper.IsGtk())
 
@@ -376,10 +396,9 @@ class MainApp(wx.App):
         self.config=bp_config.Config(self._config_filename)
         # Check to see if we're the 2nd instance running on the same DB
         if self.usingsamedb():
-            wx.MessageDialog(None,
-                             'Another copy of BitPim is using the same data dir:\n%s'%self.config._path,
-                             'BitPim Error',
-                             style=wx.OK|wx.ICON_ERROR).ShowModal()
+            guihelper.MessageDialog(None, 'Another copy of BitPim is using the same data dir:\n%s'%self.config._path,
+                                    'BitPim Error',
+                                    style=wx.OK|wx.ICON_ERROR)
             return False
         # this is for wx native use, like the freaking help controller !
         self.wxconfig=wx.Config(cfgstr, style=wx.CONFIG_USE_LOCAL_FILE)
@@ -1060,8 +1079,10 @@ class MainWindow(wx.Frame):
     # deal with configuring the phone (commport)
     def OnEditSettings(self, _=None):
         if wx.IsBusy():
-            wx.MessageBox("BitPim is busy.  You can't change settings until it has finished talking to your phone.",
-                         "BitPim is busy.", wx.OK|wx.ICON_EXCLAMATION)
+            with guihelper.WXDialogWrapper(wx.MessageBox("BitPim is busy.  You can't change settings until it has finished talking to your phone.",
+                                                         "BitPim is busy.", wx.OK|wx.ICON_EXCLAMATION),
+                                           True):
+                pass
         else:
             # clear the ower's name for manual setting
             self.__owner_name=''
@@ -1134,8 +1155,8 @@ class MainWindow(wx.Frame):
                              "Phone Info Error", style=wx.OK)
         else:
             dlg=phoneinfo.PhoneInfoDialog(self, phone_info)
-        dlg.ShowModal()
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(dlg, True):
+            pass
 
     def OnDetectPhone(self, _=None):
         if wx.IsBusy():
@@ -1183,19 +1204,17 @@ class MainWindow(wx.Frame):
         s=None
         if phone_name=='<None/>':
             # not seen before
-            dlg=guiwidgets.AskPhoneNameDialog(
-                self, 'A new phone has been detected,\n'
-                "Would you like to enter the owner's name:", style=style)
-            r=dlg.ShowModal()
-            if r==wx.ID_OK:
-                # user gave a name
-                s=dlg.GetValue()
-            elif r==wx.ID_CANCEL:
-                s=''
-            if s is not None:
-                self.config.Write(phone_id, s)
-            dlg.Destroy()
-            return s
+            with guihelper.WXDialogWrapper(guiwidgets.AskPhoneNameDialog(self, 'A new phone has been detected,\n'
+                                                                         "Would you like to enter the owner's name:", style=style),
+                                           True) as (dlg, r):
+                if r==wx.ID_OK:
+                    # user gave a name
+                    s=dlg.GetValue()
+                elif r==wx.ID_CANCEL:
+                    s=''
+                if s is not None:
+                    self.config.Write(phone_id, s)
+                return s
         return phone_name
         
     def OnDetectPhoneReturn(self, check_auto_sync, silent_fail, exception, r):
@@ -1205,12 +1224,12 @@ class MainWindow(wx.Frame):
         if r is None:
             if not silent_fail:
                 self.__owner_name=''
-                _dlg=wx.MessageDialog(self, 'No phone detected/recognized.\nRun Settings?',
-                                      'Phone Detection Failed', wx.YES_NO)
-                if _dlg.ShowModal()==wx.ID_YES:
-                    wx.CallAfter(self.OnEditSettings)
-                _dlg.Destroy()
-                self.SetPhoneModelStatus(guiwidgets.SB_Phone_Set)
+                with guihelper.WXDialogWrapper(wx.MessageDialog(self, 'No phone detected/recognized.\nRun Settings?',
+                                                                'Phone Detection Failed', wx.YES_NO),
+                                               True) as (_dlg, retcode):
+                    if retcode==wx.ID_YES:
+                        wx.CallAfter(self.OnEditSettings)
+                    self.SetPhoneModelStatus(guiwidgets.SB_Phone_Set)
         else:
             if silent_fail:
                 self.__owner_name=None
@@ -1348,94 +1367,96 @@ class MainWindow(wx.Frame):
             return
         self._autodetect_delay=self.phoneprofile.autodetect_delay
         todo.append((self.wt.rebootcheck, "Phone Reboot"))
+        wx.GetApp().critical.set()
         self.MakeCall(Request(self.wt.getdata, dlg, todo),
                       Callback(self.OnDataGetPhoneResults))
 
     def OnDataGetPhoneResults(self, exception, results):
-        if self.HandleException(exception): return
-        self.OnLog(`results.keys()`)
-        self.OnLog(`results['sync']`)
-        # phonebook
-        if results['sync'].has_key('phonebook'):
-            v=results['sync']['phonebook']
+        with wx.GetApp().critical:
+            if self.HandleException(exception): return
+            self.OnLog(`results.keys()`)
+            self.OnLog(`results['sync']`)
+            # phonebook
+            if results['sync'].has_key('phonebook'):
+                v=results['sync']['phonebook']
 
-            print "phonebookmergesetting is",v
-            if v=='MERGE': 
-                merge=True
-            else:
-                merge=False
-            self.GetActivePhonebookWidget().importdata(results['phonebook'], results.get('categories', []), merge)
+                print "phonebookmergesetting is",v
+                if v=='MERGE': 
+                    merge=True
+                else:
+                    merge=False
+                self.GetActivePhonebookWidget().importdata(results['phonebook'], results.get('categories', []), merge)
 
-        # wallpaper
-        updwp=False # did we update the wallpaper
-        if results['sync'].has_key('wallpaper'):
-            v=results['sync']['wallpaper']
-            if v=='MERGE': raise Exception("Not implemented")
-            updwp=True
-            self.GetActiveWallpaperWidget().populatefs(results)
-            self.GetActiveWallpaperWidget().populate(results)
-        # wallpaper-index
-        if not updwp and results.has_key('wallpaper-index'):
-            self.GetActiveWallpaperWidget().updateindex(results)
-        # ringtone
-        updrng=False # did we update ringtones
-        if results['sync'].has_key('ringtone'):
-            v=results['sync']['ringtone']
-            if v=='MERGE': raise Exception("Not implemented")
-            updrng=True
-            self.GetActiveRingerWidget().populatefs(results)
-            self.GetActiveRingerWidget().populate(results)
-        # ringtone-index
-        if not updrng and results.has_key('ringtone-index'):
-            self.GetActiveRingerWidget().updateindex(results)            
-        # calendar
-        if results['sync'].has_key('calendar'):
-            v=results['sync']['calendar']
-            if v=='MERGE': raise Exception("Not implemented")
-            results['calendar_version']=self.phoneprofile.BP_Calendar_Version
-            self.GetActiveCalendarWidget().mergedata(results)
-##            self.GetActiveCalendarWidget().populatefs(results)
-##            self.GetActiveCalendarWidget().populate(results)
-        # memo
-        if results['sync'].has_key('memo'):
-            v=results['sync']['memo']
-            if v=='MERGE': raise Exception("Not implemented")
-            self.GetActiveMemoWidget().populatefs(results)
-            self.GetActiveMemoWidget().populate(results)
-        # todo
-        if results['sync'].has_key('todo'):
-            v=results['sync']['todo']
-            if v=='MERGE': raise NotImplementedError
-            self.GetActiveTodoWidget().populatefs(results)
-            self.GetActiveTodoWidget().populate(results)
-        # SMS
-        if results['sync'].has_key('sms'):
-            v=results['sync']['sms']
-            if v=='MERGE':
-                self.GetActiveSMSWidget().merge(results)
-            else:
-                self.GetActiveSMSWidget().populatefs(results)
-                self.GetActiveSMSWidget().populate(results)
-        # call history
-        if results['sync'].has_key('call_history'):
-            v=results['sync']['call_history']
-            if v=='MERGE':
-                self.GetActiveCallHistoryWidget().merge(results)
-            else:
-                self.GetActiveCallHistoryWidget().populatefs(results)
-                self.GetActiveCallHistoryWidget().populate(results)
-        # Playlist
-        if results['sync'].has_key(playlist.playlist_key):
-            if results['sync'][playlist.playlist_key]=='MERGE':
-                raise NotImplementedError
-            self.GetActivePlaylistWidget().populatefs(results)
-            self.GetActivePlaylistWidget().populate(results)
-        # T9 User DB
-        if results['sync'].has_key(t9editor.dict_key):
-            if results['sync'][t9editor.dict_key]=='MERGE':
-                raise NotImplementedError
-            self.GetActiveT9EditorWidget().populatefs(results)
-            self.GetActiveT9EditorWidget().populate(results)
+            # wallpaper
+            updwp=False # did we update the wallpaper
+            if results['sync'].has_key('wallpaper'):
+                v=results['sync']['wallpaper']
+                if v=='MERGE': raise Exception("Not implemented")
+                updwp=True
+                self.GetActiveWallpaperWidget().populatefs(results)
+                self.GetActiveWallpaperWidget().populate(results)
+            # wallpaper-index
+            if not updwp and results.has_key('wallpaper-index'):
+                self.GetActiveWallpaperWidget().updateindex(results)
+            # ringtone
+            updrng=False # did we update ringtones
+            if results['sync'].has_key('ringtone'):
+                v=results['sync']['ringtone']
+                if v=='MERGE': raise Exception("Not implemented")
+                updrng=True
+                self.GetActiveRingerWidget().populatefs(results)
+                self.GetActiveRingerWidget().populate(results)
+            # ringtone-index
+            if not updrng and results.has_key('ringtone-index'):
+                self.GetActiveRingerWidget().updateindex(results)            
+            # calendar
+            if results['sync'].has_key('calendar'):
+                v=results['sync']['calendar']
+                if v=='MERGE': raise Exception("Not implemented")
+                results['calendar_version']=self.phoneprofile.BP_Calendar_Version
+                self.GetActiveCalendarWidget().mergedata(results)
+    ##            self.GetActiveCalendarWidget().populatefs(results)
+    ##            self.GetActiveCalendarWidget().populate(results)
+            # memo
+            if results['sync'].has_key('memo'):
+                v=results['sync']['memo']
+                if v=='MERGE': raise Exception("Not implemented")
+                self.GetActiveMemoWidget().populatefs(results)
+                self.GetActiveMemoWidget().populate(results)
+            # todo
+            if results['sync'].has_key('todo'):
+                v=results['sync']['todo']
+                if v=='MERGE': raise NotImplementedError
+                self.GetActiveTodoWidget().populatefs(results)
+                self.GetActiveTodoWidget().populate(results)
+            # SMS
+            if results['sync'].has_key('sms'):
+                v=results['sync']['sms']
+                if v=='MERGE':
+                    self.GetActiveSMSWidget().merge(results)
+                else:
+                    self.GetActiveSMSWidget().populatefs(results)
+                    self.GetActiveSMSWidget().populate(results)
+            # call history
+            if results['sync'].has_key('call_history'):
+                v=results['sync']['call_history']
+                if v=='MERGE':
+                    self.GetActiveCallHistoryWidget().merge(results)
+                else:
+                    self.GetActiveCallHistoryWidget().populatefs(results)
+                    self.GetActiveCallHistoryWidget().populate(results)
+            # Playlist
+            if results['sync'].has_key(playlist.playlist_key):
+                if results['sync'][playlist.playlist_key]=='MERGE':
+                    raise NotImplementedError
+                self.GetActivePlaylistWidget().populatefs(results)
+                self.GetActivePlaylistWidget().populate(results)
+            # T9 User DB
+            if results['sync'].has_key(t9editor.dict_key):
+                if results['sync'][t9editor.dict_key]=='MERGE':
+                    raise NotImplementedError
+                self.GetActiveT9EditorWidget().populatefs(results)
+                self.GetActiveT9EditorWidget().populate(results)
     ###
     ### Main bit for sending data to the phone
     ###
@@ -1565,8 +1586,10 @@ class MainWindow(wx.Frame):
         
     def OnAutoSyncSettings(self, _=None):
         if wx.IsBusy():
-            wx.MessageBox("BitPim is busy.  You can't change settings until it has finished talking to your phone.",
-                         "BitPim is busy.", wx.OK|wx.ICON_EXCLAMATION)
+            with guihelper.WXDialogWrapper(wx.MessageBox("BitPim is busy.  You can't change settings until it has finished talking to your phone.",
+                                                         "BitPim is busy.", wx.OK|wx.ICON_EXCLAMATION),
+                                           True):
+                pass
         else:
             # clear the ower's name for manual setting
             self.__owner_name=''
@@ -1625,9 +1648,7 @@ class MainWindow(wx.Frame):
             self.tree.lwdata.log(str)
         if str.startswith("<!= "):
             p=str.index("=!>")+3
-            dlg=wx.MessageDialog(self, str[p:], "Alert", style=wx.OK|wx.ICON_EXCLAMATION)
-            dlg.ShowModal()
-            dlg.Destroy()
+            guihelper.MessageDialog(self, str[p:], "Alert", style=wx.OK|wx.ICON_EXCLAMATION)
             self.OnLog("Alert dialog closed")
     log=OnLog
     def OnLogData(self, str, data, klass=None, data_type=None):
@@ -1706,9 +1727,9 @@ class MainWindow(wx.Frame):
             
         if text is not None:
             self.OnLog("Error: "+title+"\n"+text)
-            dlg=guiwidgets.AlertDialogWithHelp(self,text, title, help, style=style)
-            dlg.ShowModal()
-            dlg.Destroy()
+            with guihelper.WXDialogWrapper(guiwidgets.AlertDialogWithHelp(self,text, title, help, style=style),
+                                           True):
+                pass
             return True
 
         if self.exceptiondialog is None:
@@ -1757,9 +1778,9 @@ class MainWindow(wx.Frame):
 
     # Data Recording stuff
     def OnDataRecording(self, _):
-        _dlg=guiwidgets.DRRecFileDialog(self)
-        _dlg.ShowModal()
-        _dlg.Destroy()
+        with guihelper.WXDialogWrapper(guiwidgets.DRRecFileDialog(self),
+                                       True):
+            pass
 
     # plumbing for the multi-threading
 
@@ -2090,39 +2111,36 @@ class WorkerThread(WorkerThreadFramework):
         keys.sort()
         
         op=cStringIO.StringIO()
-        zip=zipfile.ZipFile(op, "w", zipfile.ZIP_DEFLATED)
-
-        count=0
-        for k in keys:
-            try:
-                count+=1
-                if files[k]['type']!='file':
-                    continue
-                self.progressmajor(count, len(keys)+1, "Getting files")
-                # get the contents
-                contents=self.getfile(k)
-                # an artificial sleep. if you get files too quickly, the 4400 eventually
-                # runs out of buffers and returns truncated packets
-                time.sleep(0.3)
-                # add to zip file
-                zi=zipfile.ZipInfo()
-                # zipfile does not like unicode. cp437 works on windows well, may be
-                # a better choice than ascii, but no phones currently support anything
-                # other than ascii for filenames
-                if k[strip]=='/':
-                    zi.filename=common.get_ascii_string(k[strip+1:], 'ignore')
-                else:
-                    zi.filename=common.get_ascii_string(k[strip:], 'ignore')
-                if files[k]['date'][0]==0:
-                    zi.date_time=(0,0,0,0,0,0)
-                else:
-                    zi.date_time=time.gmtime(files[k]['date'][0])[:6]
-                zi.compress_type=zipfile.ZIP_DEFLATED
-                zip.writestr(zi, contents)
-            except:
-                self.log('Failed to read file: '+k)
-        zip.close()
-
+        with contextlib.closing(zipfile.ZipFile(op, "w", zipfile.ZIP_DEFLATED)) as zip:
+            count=0
+            for k in keys:
+                try:
+                    count+=1
+                    if files[k]['type']!='file':
+                        continue
+                    self.progressmajor(count, len(keys)+1, "Getting files")
+                    # get the contents
+                    contents=self.getfile(k)
+                    # an artificial sleep. if you get files too quickly, the 4400 eventually
+                    # runs out of buffers and returns truncated packets
+                    time.sleep(0.3)
+                    # add to zip file
+                    zi=zipfile.ZipInfo()
+                    # zipfile does not like unicode. cp437 works on windows well, may be
+                    # a better choice than ascii, but no phones currently support anything
+                    # other than ascii for filenames
+                    if k[strip]=='/':
+                        zi.filename=common.get_ascii_string(k[strip+1:], 'ignore')
+                    else:
+                        zi.filename=common.get_ascii_string(k[strip:], 'ignore')
+                    if files[k]['date'][0]==0:
+                        zi.date_time=(0,0,0,0,0,0)
+                    else:
+                        zi.date_time=time.gmtime(files[k]['date'][0])[:6]
+                    zi.compress_type=zipfile.ZIP_DEFLATED
+                    zip.writestr(zi, contents)
+                except:
+                    self.log('Failed to read file: '+k)
         return op.getvalue()
     
     def restorefiles(self, files):
