@@ -7,11 +7,13 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: guiwidgets.py 4230 2007-05-10 22:52:21Z djpham $
+### $Id: guiwidgets.py 4412 2007-09-28 01:28:56Z djpham $
 
 """Most of the graphical user interface elements making up BitPim"""
 
 # standard modules
+from __future__ import with_statement
+import contextlib
 import os
 import sys
 import time
@@ -19,12 +21,12 @@ import copy
 import StringIO
 import getpass
 import sha,md5
-import zlib
+import gzip
 import base64
 import thread
 import Queue
 import shutil
-import time
+import platform
 
 # wx. modules
 import wx
@@ -36,6 +38,7 @@ import wx.lib.stattext as stattext
 from wx.lib.masked import NumCtrl
 
 # my modules
+import apsw
 import common
 import version
 import helpids
@@ -55,6 +58,7 @@ import phones
 import setphone_wizard
 import data_recording
 import xyaptu
+import serial
 
 ###
 ### BitFling cert stuff
@@ -154,7 +158,10 @@ class LogWindow(wx.Panel, widgets.BitPimWidget):
             self.theanalyser.Show()
             self.theanalyser.newdata(data)
             evt.Skip()
-            
+
+    def GetValue(self):
+        """return the log text"""
+        return self.tb.GetValue()
 
 
 ###
@@ -416,6 +423,14 @@ class ConfigDialog(wx.Dialog):
         gs.Add( self.commbox, pos=(_row,1), flag=wx.ALIGN_CENTER_VERTICAL)
         gs.Add( wx.Button(self, self.ID_COMBROWSE, "Browse ..."), pos=(_row,2), flag=wx.ALIGN_CENTER_VERTICAL)
         _row+=1
+        # com timeout
+        gs.Add(wx.StaticText(self, -1, 'Com Timeout (sec)'), pos=(_row, 0),
+               flag=wx.ALIGN_CENTER_VERTICAL)
+        self.commtimeout=NumCtrl(self, -1,
+                                 integerWidth=2, fractionWidth=1,
+                                 allowNegative=False)
+        gs.Add(self.commtimeout, pos=(_row, 1), flag=wx.ALIGN_CENTER_VERTICAL)
+        _row+=1
 
         # Automatic check for update
         gs.Add(wx.StaticText(self, -1, 'Check for Update'), pos=(_row,0), flag=wx.ALIGN_CENTER_VERTICAL)
@@ -534,20 +549,11 @@ class ConfigDialog(wx.Dialog):
         # w=self.mw.config.ReadInt("combrowsewidth", 640)
         # h=self.mw.config.ReadInt("combrowseheight", 480)
         p=self.mw.config.ReadInt("combrowsesash", 200)
-        dlg=CommPortDialog(self, common.importas(phones.module(self.phonebox.GetValue())), defaultport=self.commbox.GetValue(), sashposition=p)
-        # dlg.SetSize(wx.Size(w,h))
-        # dlg.Centre()
-        res=dlg.ShowModal()
-        v=dlg.GetPort()
-        
-        # sz=dlg.GetSize()
-        # self.mw.config.WriteInt("combrowsewidth", sz.GetWidth())
-        # self.mw.config.WriteInt("combrowseheight", sz.GetHeight())
-
-        self.mw.config.WriteInt("combrowsesash", dlg.sashposition)
-        dlg.Destroy()
-        if res==wx.ID_OK:
-            self.commbox.SetValue(v)
+        with guihelper.WXDialogWrapper(CommPortDialog(self, common.importas(phones.module(self.phonebox.GetValue())), defaultport=self.commbox.GetValue(), sashposition=p),
+                                       True) as (dlg, res):
+            self.mw.config.WriteInt("combrowsesash", dlg.sashposition)
+            if res==wx.ID_OK:
+                self.commbox.SetValue(dlg.GetPort())
 
     def ApplyBitFlingSettings(self, _=None):
         if self.bitflingenabled is not None:
@@ -561,10 +567,10 @@ class ConfigDialog(wx.Dialog):
                 bitflingscan.flinger.unconfigure()
 
     def OnBitFlingSettings(self, _):
-        dlg=BitFlingSettingsDialog(None, self.mw.config)
-        if dlg.ShowModal()==wx.ID_OK:
-            dlg.SaveSettings()
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(BitFlingSettingsDialog(None, self.mw.config),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                dlg.SaveSettings()
         self.ApplyBitFlingSettings()
         if self.mw.config.Read("bitfling/password","<unconfigured>") \
                != "<unconfigured>":
@@ -638,6 +644,7 @@ class ConfigDialog(wx.Dialog):
     def setfromconfig(self):
         if len(self.mw.config.Read("lgvx4400port")):
             self.commbox.SetValue(self.mw.config.Read("lgvx4400port", ""))
+        self.commtimeout.SetValue(self.mw.config.ReadFloat('commtimeout', 3.0))
         if self.mw.config.Read("phonetype", "") in self.phonemodels:
             self.phonebox.SetValue(self.mw.config.Read("phonetype"))
         if self.bitflingenabled is not None:
@@ -671,12 +678,14 @@ class ConfigDialog(wx.Dialog):
         self.mw.configpath=path
         self.mw.commportsetting=str(self.commbox.GetValue())
         self.mw.config.Write("lgvx4400port", self.mw.commportsetting)
+        self.mw.config.WriteFloat('commtimeout',
+                                  float(self.commtimeout.GetValue()))
         if self.mw.wt is not None:
             self.mw.wt.clearcomm()
         # comm parameters (retry, timeouts, flow control etc)
         commparm={}
         commparm['retryontimeout']=self.mw.config.ReadInt("commretryontimeout", False)
-        commparm['timeout']=self.mw.config.ReadInt('commtimeout', 3)
+        commparm['timeout']=self.mw.config.ReadFloat('commtimeout', 3.0)
         commparm['hardwareflow']=self.mw.config.ReadInt('commhardwareflow', False)
         commparm['softwareflow']=self.mw.config.ReadInt('commsoftwareflow', False)
         commparm['baud']=self.mw.config.ReadInt('commbaud', 115200)
@@ -884,11 +893,11 @@ class CommPortDialog(wx.Dialog):
             print >>html, "<tr><td colspan=3>%s</td></tr>" % (desc,)
             print >>html, "<tr><td colspan=3><hr></td></tr>"
         print >>html, "</table></body></html>"
-        dlg=wx.FileDialog(self, "Save port details as", defaultFile="bitpim-ports.html", wildcard="HTML files (*.html)|*.html",
-                         style=wx.SAVE|wx.OVERWRITE_PROMPT|wx.CHANGE_DIR)
-        if dlg.ShowModal()==wx.ID_OK:
-            open(dlg.GetPath(), "wt").write(html.getvalue())
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(wx.FileDialog(self, "Save port details as", defaultFile="bitpim-ports.html", wildcard="HTML files (*.html)|*.html",
+                                                     style=wx.SAVE|wx.OVERWRITE_PROMPT|wx.CHANGE_DIR),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                file(dlg.GetPath(), "wt").write(html.getvalue())
 
     def OnCancel(self, _):
         self.saveSize()
@@ -1065,18 +1074,14 @@ class BitFlingSettingsDialog(wx.Dialog):
         try:
             bitflingscan.flinger.configure(*self.GetSettings())
             res=bitflingscan.flinger.getversion()
-            dlg=wx.MessageDialog(self, "Succeeded. Remote version is %s" % (res,) , "Success", wx.OK|wx.ICON_INFORMATION)
-            dlg.ShowModal()
-            dlg.Destroy()
+            guihelper.MessageDialog(self, "Succeeded. Remote version is %s" % (res,) , "Success", wx.OK|wx.ICON_INFORMATION)
         except Exception,ex:
             res="Failed: %s: %s" % sys.exc_info()[:2]
             if hasattr(ex, "gui_exc_info"):
                 print common.formatexception( ex.gui_exc_info)
             else:
                 print common.formatexception()
-            dlg=wx.MessageDialog(self, res, "Failed", wx.OK|wx.ICON_ERROR)
-            dlg.ShowModal()
-            dlg.Destroy()
+            guihelper.MessageDialog(self, res, "Failed", wx.OK|wx.ICON_ERROR)
 
 
 ###
@@ -1133,15 +1138,18 @@ class ExceptionDialog(wx.Dialog):
         vbs=wx.BoxSizer(wx.VERTICAL)
         vbs.Add(self.maintext, 1, wx.EXPAND|wx.ALL, 5)
 
-        buttsizer=wx.GridSizer(1, 3)
+        buttsizer=wx.GridSizer(1, 4)
         buttsizer.Add(wx.Button(self, wx.ID_CANCEL, "Abort BitPim"), 0, wx.ALL, 10)
         buttsizer.Add(wx.Button(self, wx.ID_HELP, "Help"), 0, wx.ALL, 10)
         buttsizer.Add(wx.Button(self, wx.ID_OK, "Continue"), 0, wx.ALL, 10)
+        _id=wx.NewId()
+        buttsizer.Add(wx.Button(self, _id, "Create Trouble Report"), 0, wx.ALL, 10)
 
         vbs.Add(buttsizer, 0, wx.ALIGN_RIGHT|wx.ALL, 5)
 
         wx.EVT_BUTTON(self, wx.ID_CANCEL, self.abort)
         wx.EVT_BUTTON(self, wx.ID_HELP, lambda _: wx.GetApp().displayhelpid(helpids.ID_EXCEPTION_DIALOG))
+        wx.EVT_BUTTON(self, _id, self.OnCreateReport)
         
         self.SetSizer(vbs)
         self._text=""
@@ -1164,6 +1172,127 @@ class ExceptionDialog(wx.Dialog):
     def getexceptiontext(self):
         return self._text
 
+    def OnCreateReport(self, _):
+        with guihelper.WXDialogWrapper(CreateTroubleReportDialog(self.GetParent()),
+                                       True) as (_dlg, retcode):
+            if retcode==wx.ID_OK:
+                try:
+                    self._create_report(_dlg.GetValue())
+                    guihelper.MessageDialog(self,
+                                            'Trouble Report created successfully!',
+                                            'BitPim Trouble Report', style=wx.OK)
+                except:
+                    guihelper.MessageDialog(self,
+                                            'Failed to Create Trouble Report',
+                                            'Trouble Report Error',
+                                            style=wx.OK|wx.ICON_ERROR)
+
+    def _create_report(self, vals):
+        with contextlib.closing(gzip.GzipFile(vals['filename'], 'wb')) as _s:
+            _s.write('BitPim Trouble Report\n')
+            _s.write(time.asctime()+'\n')
+            _s.write('BitPim Version: %s - %s\n'%(version.versionstring, version.vendor))
+            _s.write('Platorm: %s, Architecture: %s %s, Dist: %s %s %s\n'%\
+                        ((platform.platform(),)+platform.architecture()+\
+                         platform.dist()))
+            # phone model if available
+            try:
+                _model=self.GetParent().phonemodule.Phone.desc
+            except:
+                _model='Not Available'
+            _s.write('Phone Model: %s\n'%_model)
+            _s.write('Name: %s\n'%vals['name'])
+            _s.write('email: %s\n'%vals['email'])
+            _s.write('Description: %s\n'%vals['description'])
+            _s.write('Exception:\n%s\n'%self._text)
+            # write out log data if evailable
+            try:
+                _log=self.GetParent().tree.lw.GetValue()
+            except:
+                # don't care if we can't get the log
+                _log='Not Available'
+            _s.write('BitPim Log:\n%s\n'%_log)
+            # write out protocol data if available
+            try:
+                _log=self.GetParent().tree.lwdata.GetValue()
+            except:
+                _log='Not Available'
+            _s.write('BitPim Protocol Data:\n%s\n'%_log)
+
+class CreateTroubleReportDialog(wx.Dialog):
+
+    _default_filename='bpbug.gz'
+    def __init__(self, parent):
+        wx.Dialog.__init__(self, parent, -1, 'BitPim Trouble Report',
+                          style=wx.CAPTION|wx.SYSTEM_MENU|wx.DEFAULT_DIALOG_STYLE)
+
+        gs=wx.GridBagSizer(10, 10)
+        gs.AddGrowableCol(1)
+        _width=300
+        _row=0
+        # Name
+        gs.Add( wx.StaticText(self, -1, "Name:"), pos=(_row,0),
+                flag=wx.ALIGN_CENTER_VERTICAL)
+        self._name=wx.TextCtrl(self, -1, '', size=(_width,-1))
+        gs.Add(self._name, pos=(_row, 1), flag=wx.ALIGN_CENTER_VERTICAL)
+        _row+=1
+        # email
+        gs.Add( wx.StaticText(self, -1, "email:"), pos=(_row,0), flag=wx.ALIGN_CENTER_VERTICAL)
+        self._email=wx.TextCtrl(self, -1, '', size=(_width,-1))
+        gs.Add(self._email, pos=(_row, 1), flag=wx.ALIGN_CENTER_VERTICAL)
+        _row+=1
+        # trouble report file name
+        gs.Add( wx.StaticText(self, -1, "File Name:"), pos=(_row,0), flag=wx.ALIGN_CENTER_VERTICAL)
+        self._filename=wx.TextCtrl(self, -1, self._default_filename,
+                                   size=(_width,-1))
+        gs.Add(self._filename, pos=(_row, 1), flag=wx.ALIGN_CENTER_VERTICAL)
+        _browseid=wx.NewId()
+        gs.Add(wx.Button(self, _browseid, 'Browse ...'), pos=(_row, 2),
+               flag=wx.ALIGN_CENTER_VERTICAL)
+        _row+=1
+        # Trouble Description
+        gs.Add(wx.StaticText(self, -1, 'Trouble Description:'), pos=(_row, 0),
+               flag=wx.ALIGN_CENTER_VERTICAL)
+        self._desc=wx.TextCtrl(self, -1, '',
+                               style=wx.TE_MULTILINE|wx.TE_BESTWRAP,
+                               size=(_width, 100))
+        gs.Add(self._desc, pos=(_row, 1), flag=wx.ALIGN_CENTER_VERTICAL)
+        _row+=1
+
+        # crud at the bottom
+        bs=wx.BoxSizer(wx.VERTICAL)
+        bs.Add(gs, 0, wx.EXPAND|wx.ALL, 10)
+        bs.Add(wx.StaticLine(self, -1), 0, wx.EXPAND|wx.TOP|wx.BOTTOM, 7)
+        
+        but=self.CreateButtonSizer(wx.OK|wx.CANCEL|wx.HELP)
+        bs.Add(but, 0, wx.CENTER|wx.ALL, 10)
+
+        wx.EVT_BUTTON(self, wx.ID_HELP, self.OnHelp)
+        wx.EVT_BUTTON(self, _browseid, self.OnBrowse)
+
+        self.SetSizer(bs)
+        self.SetAutoLayout(True)
+        bs.Fit(self)
+
+    def OnHelp(self, _):
+        wx.GetApp().displayhelpid(helpids.ID_TROUBLEREPORT)
+    def OnBrowse(self, _):
+        # how to select a source, default to select a file
+        with guihelper.WXDialogWrapper(wx.FileDialog(self, self._filename.GetValue(),
+                                                     defaultFile=self._filename.GetValue(),
+                                                     style=wx.FD_SAVE|wx.FD_OVERWRITE_PROMPT,
+                                                     wildcard='gzip files|*.gz'),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                self._filename.SetValue(dlg.GetPath())
+    def GetValue(self):
+        # return a dict of values of this dialog
+        return { 'name': self._name.GetValue(),
+                 'email': self._email.GetValue(),
+                 'filename': self._filename.GetValue(),
+                 'description': self._desc.GetValue(),
+                 }
+
 ###
 ###  Too much freaking effort for a simple statusbar.  Mostly copied from the demo.
 ###
@@ -1878,8 +2007,9 @@ class DRRecFileDialog(wx.Dialog):
     def OnBrowse(self, _):
         _dlg=wx.FileDialog(self)
         _dlg.SetPath(self._file_name.GetValue())
-        if _dlg.ShowModal()==wx.ID_OK:
-            self._file_name.SetValue(_dlg.GetPath())
+        with guihelper.WXDialogWrapper(_dlg, True) as (_dlg, retcode):
+            if retcode==wx.ID_OK:
+                self._file_name.SetValue(_dlg.GetPath())
 
     def OnView(self, _):
         _dr_file=data_recording.DR_Read_File(self._file_name.GetValue())
@@ -1901,12 +2031,12 @@ class DRRecFileDialog(wx.Dialog):
         if not data_recording.DR_Play:
             # not playing back, start playing
             self.OnPlay()
-        _dlg=wx.SingleChoiceDialog(self, 'Select the Starting Point',
-                                   'Data Recording Set Start',
-                                   choices=data_recording.get_headers())
-        if _dlg.ShowModal()==wx.ID_OK:
-            data_recording.set_start(_dlg.GetSelection())
-        _dlg.Destroy()
+        with guihelper.WXDialogWrapper(wx.SingleChoiceDialog(self, 'Select the Starting Point',
+                                                             'Data Recording Set Start',
+                                                             choices=data_recording.get_headers()),
+                                       True) as (_dlg, retcode):
+            if retcode==wx.ID_OK:
+                data_recording.set_start(_dlg.GetSelection())
 
 # About Dialog-----------------------------------------------------------------
 _license="""The BitPim code is under the GNU General Public License as detailed
@@ -1950,17 +2080,42 @@ _description="""    BitPim is a program that allows you to view and manipulate d
     Filesystem for most Qualcomm CDMA chipset based phones. To see when phones will
     be supported, which ones are already supported and which features are supported,
     see online help.
+    
+[%s]
 """
+def _component_string():
+    """return a CSV string of various software components being used by BitPim"""
+    _res=[]
+    _str=[]
+    # Python version
+    _str.append('Python %s'%sys.version.split()[0])
+    _str.append('wxPython %s'%wx.version())
+    _res.append(', '.join(_str))
+    _str=[]
+    _str.append('APSW %s'%apsw.apswversion())
+    _str.append('SQLITE %s'%apsw.sqlitelibversion())
+    _res.append(', '.join(_str))
+    _str=[]
+    _str.append('serial %s'%serial.VERSION)
+    # pywin32 version
+    try:
+        _pywin32ver=file(os.path.join(sys.prefix,'lib','site-packages', 'pywin32.version.txt'),
+                         'rt').read()[:-1]        
+        _str.append('pywin32 %s'%_pywin32ver)
+    except:
+        pass
+    _res.append(', '.join(_str))
+    return '\n'.join(_res)
+
 def show_about_dlg(parent):
     global _license, _copyright, _description
     info = wx.AboutDialogInfo()
     info.Name = "BitPim"
     info.Version = version.versionstring+" - "+version.vendor
     info.Copyright=_copyright
-    info.Description = _description
+    info.Description = _description%_component_string()
     info.WebSite = ("http://www.bitpim.org", "www.bitpim.org")
-    info.Developers = [ "Roger Binns",
-                        "Joe Pham",
+    info.Developers = [ "Joe Pham",
                         "Stephen Wood",
                         "Sean Burke",
                         "Nathan Hjelm",
@@ -2059,12 +2214,12 @@ class PrintDialog(wx.Dialog):
         self._gen_print_data()
         wx.GetApp().htmlprinter.PreviewText(self._html)
     def OnSaveHTML(self, _):
-        _dlg=wx.FileDialog(self, wildcard="Web Page (*.htm;*.html)|*.htm;*html",
-                           style=wx.FD_SAVE|wx.FD_OVERWRITE_PROMPT)
-        if _dlg.ShowModal()==wx.ID_OK:
-            self._gen_print_data()
-            file(_dlg.GetPath(), 'wt').write(self._html)
-        _dlg.Destroy()
+        with guihelper.WXDialogWrapper(wx.FileDialog(self, wildcard="Web Page (*.htm;*.html)|*.htm;*html",
+                                                     style=wx.FD_SAVE|wx.FD_OVERWRITE_PROMPT),
+                                       True) as (_dlg, retcode):
+            if retcode==wx.ID_OK:
+                self._gen_print_data()
+                file(_dlg.GetPath(), 'wt').write(self._html)
     def OnClose(self, _):
         try:
             # remove the temp file, ignore exception if file does not exist
