@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: package.py 4287 2007-06-12 02:33:21Z djpham $
+### $Id: package.py 4394 2007-09-10 03:25:47Z djpham $
 
 # This file provides the packaging definitions used by the buildrelease system
 
@@ -24,19 +24,19 @@ def sanitycheck():
     print "=== Sanity check ==="
 
     print "svn location",
-    if not "$HeadURL: https://bitpim.svn.sourceforge.net/svnroot/bitpim/releases/1.0.0/src/package.py $".split(":",1)[1].strip().startswith("https://bitpim.svn.sourceforge.net"):
+    if not "$HeadURL: https://bitpim.svn.sourceforge.net/svnroot/bitpim/releases/1.0.2/src/package.py $".split(":",1)[1].strip().startswith("https://bitpim.svn.sourceforge.net"):
         raise Exception("Needs to be checked out from https://bitpim.svn.sourceforge.net")
     print "  OK"
 
     print "python version",
-    if sys.version_info[:2]!=(2,3):
-       raise Exception("Should be  Python 2.3 - this is "+sys.version)
+    if sys.version_info[:2]!=(2,5):
+       raise Exception("Should be  Python 2.5 - this is "+sys.version)
     print "  OK"
 
     print "wxPython version",
     import wx
-    if wx.VERSION[:4]!=(2,8,4,0):
-        raise Exception("Should be wxPython 2.6.3.3.  This is "+`wx.VERSION`)
+    if wx.VERSION[:4]!=(2,8,4,2):
+        raise Exception("Should be wxPython 2.8.4.2.  This is "+`wx.VERSION`)
     print "  OK"
 
     print "wxPython is unicode build",
@@ -57,7 +57,7 @@ def sanitycheck():
     print "  OK"
 
     print "paramiko version",
-    expect='1.7 (zubat)'
+    expect='1.7.1 (Amy)'
     import paramiko
     if paramiko.__version__!=expect:
         raise Exception("Should be %s version of paramiko - you have %s" % (expect, paramiko.__version__))
@@ -79,7 +79,7 @@ def sanitycheck():
     print "  OK"
 
     print "sqlite",
-    ver="3.3.17"
+    ver="3.4.1"
     if apsw.sqlitelibversion()!=ver:
         raise Exception("Should be sqlite version %s - you have %s" % (ver, apsw.sqlitelibversion()))
     print "  OK"
@@ -184,6 +184,8 @@ def ensureofficial():
 
 def getversion():
     return version.version
+def setversion(versionstring, vendorstring='Test'):
+    version.setversion(versionstring, vendorstring)
 
 import phones
 import encodings
@@ -341,7 +343,7 @@ def getvals():
         'RELEASE': version.release,
         'DQVERSION': version.dqverstr,
         'COMMENTS': "Provided under the GNU Public License (GPL)",
-        'DESCRIPTION': "View and manipulate data on many CDMA phones from LG, Samsung, Sanyo and other manufacturers. This includes the PhoneBook, Calendar, WallPapers, RingTones (functionality varies by phone) and the Filesystem for most Qualcomm CDMA chipset based phones.",
+        'DESCRIPTION': "Open Source Mobile Phone Tool",
         'COPYRIGHT': "Copyright (C) 2003-2006 The BitPim developers",
         'URL': version.url,
         'SUPPORTURL': "http://www.bitpim.org/help/support.htm",
