@@ -5,8 +5,9 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: phonebookentryeditor.py 4287 2007-06-12 02:33:21Z djpham $
+### $Id: phonebookentryeditor.py 4412 2007-09-28 01:28:56Z djpham $
 
+from __future__ import with_statement
 import wx
 
 import fixedscrolledpanel
@@ -112,6 +113,12 @@ class ListBox(wx.ListBox):
             self._selstr=''
 
 # RingtoneEditor----------------------------------------------------------------
+class MediaPreviewWindow(bphtml.HTMLWindow):
+    """A subclass of BitPim HTMLWindow that launches a media item when clicked"""
+    def OnLinkClicked(self, evt):
+        pubsub.publish(pubsub.REQUEST_MEDIA_OPEN,
+                       (evt.GetHref(), None))
+
 class RingtoneEditor(DirtyUIBase):
     "Edit a ringtone"
 
@@ -135,7 +142,7 @@ class RingtoneEditor(DirtyUIBase):
         self.static_box=_box
         vs=wx.BoxSizer(wx.VERTICAL)
 
-        self.preview=bphtml.HTMLWindow(self, -1)
+        self.preview=MediaPreviewWindow(self, -1)
         self.preview.SetBorders(self._bordersize)
         vs.Add(self.preview, 1, wx.EXPAND|wx.ALL, 5)
         self.type=wx.ComboBox(self, -1, "call", choices=self.choices, style=wx.CB_READONLY)
@@ -156,12 +163,14 @@ class RingtoneEditor(DirtyUIBase):
 
         pubsub.subscribe(self.OnRingtoneUpdates, pubsub.ALL_RINGTONES)
         wx.CallAfter(pubsub.publish, pubsub.REQUEST_RINGTONES) # make the call once we are onscreen
+        pubsub.subscribe(self.OnPreviewUpdate, pubsub.RESPONSE_MEDIA_INFO)
 
         wx.EVT_LISTBOX(self, self.ID_LIST, self.OnLBClicked)
         wx.EVT_LISTBOX_DCLICK(self, self.ID_LIST, self.OnLBClicked)
 
     def __del__(self):
         pubsub.unsubscribe(self.OnRingtoneUpdates)
+        pubsub.unsubscribe(self.OnPreviewUpdate)
         super(RingtoneEditor, self).__del__()
 
     def OnRingtoneUpdates(self, msg):
@@ -185,11 +194,24 @@ class RingtoneEditor(DirtyUIBase):
         v=self._get().get('ringtone', None)
         self.SetPreview(v)
 
+    _preview_html='<img src="bpimage:ringer.png;width=24;height=24"><P>%s'
+    def OnPreviewUpdate(self, msg):
+        # Media tab replies with some description about the selected media item
+        if msg.data['client'] is self:
+            # this one's for moi!
+            if msg.data['canopen']:
+                _s='<A HREF="%s">%s</A><BR>'%(msg.data['desc'][0], msg.data['desc'][0]) +\
+                    '<BR>'.join(msg.data['desc'][1:])
+            else:
+                _s='<BR>'.join(msg.data['desc'])
+            self.preview.SetPage(self._preview_html%_s)
+
     def SetPreview(self, name):
-        if name is None:
+        if name is None or name==self.unnamed:
             self.preview.SetPage('')
         else:
-            self.preview.SetPage('<img src="bpimage:ringer.png;width=24;height=24"><br>At some point there will be info about the ringtone as well as the ability to play it here')
+            self.preview.SetPage(self._preview_html%name)
+            pubsub.publish(pubsub.REQUEST_MEDIA_INFO, (self, name, None))
 
     def _set(self, data):
         if data is None:
@@ -549,8 +571,8 @@ class CategoryEditor(DirtyUIBase):
         super(CategoryEditor, self).__del__()
 
     def OnManageCategories(self, _):
-        dlg=CategoryManager(self)
-        dlg.ShowModal()
+        with guihelper.WXDialogWrapper(CategoryManager(self), True):
+            pass
 
     def OnUpdateCategories(self, msg):
         cats=msg.data[:]
@@ -1222,7 +1244,7 @@ class MiscEditor(DirtyUIBase):
         vs.Fit(self)
 
     def Set(self, data):
-        self._storage.SetValue(data.get('sim', False) and 'SIM' or 'Phone')
+        self._storage.SetValue('SIM' if data.get('sim', False) else 'Phone')
         self._secret.SetValue(data.get('secret', False))
 
     def Get(self):
@@ -1827,5 +1849,5 @@ if __name__=='__main__':
            }
 
     app=wx.PySimpleApp()
-    dlg=Editor(None,data)
-    dlg.ShowModal()
+    with guihelper.WXDialogWrapper(Editor(None,data), True):
+        pass
