@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: __init__.py 4287 2007-06-12 02:33:21Z djpham $
+### $Id: __init__.py 4411 2007-09-27 03:56:27Z sawecw $
 
 import helpids
 
@@ -34,7 +34,12 @@ b_other='Other'
 b_audiovox='Audiovox'
 b_moto='Motorola'
 
-_phonedata= { 'LG-G4015': { 'module': 'com_lgg4015',
+_phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
+	    		     'carrier': [c_alltel],
+			     'brand': b_lg,
+			     'helpid': helpids.ID_PHONE_LGAX8600,
+	    		     },
+	      'LG-G4015': { 'module': 'com_lgg4015',
                             'carrier': [c_att],
                             'brand': b_lg,
                             'helpid': helpids.ID_PHONE_LGG4015,
@@ -139,6 +144,11 @@ _phonedata= { 'LG-G4015': { 'module': 'com_lgg4015',
                              'brand': b_lg,
                              'helpid': helpids.ID_PHONE_LGVX8500,
                              },
+              'LG-VX8550': { 'module': 'com_lgvx8550',
+                             'carrier': [c_vzw],
+                             'brand': b_lg,
+                             'helpid': None,
+                             },
               'LG-VX8600': { 'module': 'com_lgvx8600',
                              'carrier': [c_vzw],
                              'brand': b_lg,
@@ -197,6 +207,11 @@ _phonedata= { 'LG-G4015': { 'module': 'com_lgg4015',
                                      'brand': b_sanyo,
                                      'helpid': helpids.ID_PHONE_SANYOSCP6600,
                                      },
+              'SCP-6650 (Katana-II)': { 'module': 'com_sanyo6650',
+                                     'carrier': [c_sprint],
+                                     'brand': b_sanyo,
+                                     'helpid': helpids.ID_PHONE_SANYOSCP6600,
+                                     },
               'MM-7400': { 'module': 'com_sanyo7400',
                            'carrier': [c_sprint],
                            'brand': b_sanyo,
@@ -428,6 +443,16 @@ if __debug__:
                                       'carrier': [c_tmobileusa],
                                       'helpid': None,
                                       },
+                        'SPH-A900': { 'module': 'com_samsungspha900',
+                                      'carrier': [c_sprint],
+                                      'brand': b_samsung,
+                                      'helpid': helpids.ID_PHONE_SAMSUNGOTHERS,
+                                      },
+                        'SCP-3200': { 'module': 'com_sanyo3200',
+                                      'carrier': [c_sprint],
+                                      'brand': b_sanyo,
+                                      'helpid': helpids.ID_PHONE_SANYOOTHERS,
+                                      },
                         'SCP-8400': { 'module': 'com_sanyo8400',
                                       'carrier': [c_sprint],
                                       'brand': b_sanyo,
