@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_brew.py 4287 2007-06-12 02:33:21Z djpham $
+### $Id: com_brew.py 4359 2007-08-17 03:31:52Z djpham $
 
 """Implements the "Brew" filesystem protocol"""
 
@@ -72,6 +72,11 @@ class BrewFileSystemFullException(BrewCommandException):
     def __init__(self, errnum=0x16, filename=None):
         BrewCommandException.__init__(self, errnum, "The phone has run out of space to store any more files")
 
+class BrewStatFileException(BrewCommandException):
+    def __init__(self, errnum, filename):
+        BrewCommandException.__init__(self, errnum,
+                                      "Stat File %s errno %d"%(filename, errnum))
+
 
 modeignoreerrortypes=com_phone.modeignoreerrortypes+(BrewCommandException,common.CommsDataCorruption)
 
@@ -782,20 +787,15 @@ class RealBrewProtocol:
         # Starting with the vx8100/9800 verizon started to block access to some file and directories
         # it reports a bad command packet as the error when it really means access denied
         if ord(data[0])==0x13:
-            if firsttwo[0]=="Y": # brew command
+            if firsttwo[0]=="Y" or firsttwo[0]=="\x4b": # brew command
                 raise BrewAccessDeniedException()
             else:
                 raise BrewBadBrewCommandException()
         if ord(data[0])==0x14:
             raise BrewMalformedBrewCommandException()
-        # the vx8300 returns yet another error for access denied (probably related to the new brew protocol)
-        if ord(data[0])==0x4b and ord(data[1])==0x04 and ord(data[2])==0x1c:
-            raise BrewAccessDeniedException()
-        # the lx550 returns yet another error for access denied listing directories (probably related to the new brew protocol)
-        if ord(data[0])==0x4b and ord(data[1])==0x0a and ord(data[2])==0x1c:
-            raise BrewAccessDeniedException()
-        # the lx550 returns yet another error for access denied listing files in a dir (probably related to the new brew protocol)
-        if ord(data[0])==0x4b and ord(data[1])==0x0b and ord(data[2])==0x1c:
+
+        # access denied error
+        if ord(data[0])==0x4b and ord(data[2])==0x1c:
             raise BrewAccessDeniedException()
 
         # parse data
@@ -880,6 +880,10 @@ class RealBrewProtocol2:
             current_size=info['size']
         else:
             current_size=0
+        try:
+            block_size = self.protocolclass.BREW_WRITE_SIZE
+        except AttributeError:
+            block_size = p_brew.BREW_WRITE_SIZE
         # if the current file is longer than the new one we have to 
         # delete it because the write operation does not truncate it
         if exists and size<current_size:
@@ -896,8 +900,8 @@ class RealBrewProtocol2:
             while remain:
                 req=p_brew.new_writefilerequest()
                 req.handle=handle
-                if remain>243:
-                    req.bytes=243
+                if remain > block_size:
+                    req.bytes=block_size
                 else:
                     req.bytes=remain
                 req.position=size-remain
@@ -909,10 +913,8 @@ class RealBrewProtocol2:
                 if res.bytes!=req.bytes:
                     self.raisecommsexception("Brew file write error", common.CommsDataCorruption)
                 remain-=req.bytes
-        except Exception, e: # MUST close handle to file
+        finally: # MUST close handle to file
             self.closefile(handle)
-            raise Exception, e 
-        self.closefile(handle)
         self.progress(1,1,desc)
         end=time.time()
         if end-start>3:
@@ -927,6 +929,10 @@ class RealBrewProtocol2:
                 if _data:
                     return _data
                 self.log('Cache file corrupted and discarded')
+        try:
+            block_size = self.protocolclass.BREW_READ_SIZE
+        except AttributeError:
+            block_size = p_brew.BREW_READ_SIZE
         start=time.time()
         self.log("Getting file contents '"+file+"'")
         desc="Reading "+file
@@ -942,7 +948,7 @@ class RealBrewProtocol2:
                     self.progress(data.tell(), filesize, desc)
                 req=p_brew.new_readfilerequest()
                 req.handle=handle
-                req.bytes=0xEB
+                req.bytes=block_size
                 req.position=read
                 res=self.sendbrewcommand(req, p_brew.new_readfileresponse)
                 if res.bytes:
@@ -952,10 +958,8 @@ class RealBrewProtocol2:
                     break
                 if read==filesize:
                     break
-        except Exception, e: # MUST close handle to file
+        finally: # MUST close handle to file
             self.closefile(handle)
-            raise Exception, e 
-        self.closefile(handle)
         self.progress(1,1,desc)
         data=data.getvalue()
         # give the download speed if we got a non-trivial amount of data
@@ -1000,7 +1004,7 @@ class RealBrewProtocol2:
                     direntry=dir+"/"+res.entryname
                 else:
                     direntry=res.entryname
-                if files and res.type==0: # file
+                if files and res.type==0: # file or special file
                     results[direntry]={ 'name': direntry, 'type': 'file',
                                     'size': res.size }
                     try:
@@ -1015,15 +1019,11 @@ class RealBrewProtocol2:
                     if recurse>0:
                         dirs[count]=direntry
                         count+=1
-        except Exception, e: # we MUST close the handle regardless or we wont be able to list the filesystem
+        finally: # we MUST close the handle regardless or we wont be able to list the filesystem
             # reliably again without rebooting it
             req=p_brew.new_closedirectoryrequest()
             req.handle=handle
             res=self.sendbrewcommand(req, p_brew.new_closedirectoryresponse)
-            raise Exception, e
-        req=p_brew.new_closedirectoryrequest()
-        req.handle=handle
-        res=self.sendbrewcommand(req, p_brew.new_closedirectoryresponse)
         # recurse the subdirectories
         for i in range(count):
             results.update(self.getfilesystem(dirs[i], recurse-1))
@@ -1035,8 +1035,13 @@ class RealBrewProtocol2:
         req=p_brew.new_statfilerequest()
         req.filename=name
         res=self.sendbrewcommand(req, p_brew.new_statfileresponse)
-        if res.flags==2:
+        if res.error==2:    # ENOENT
             raise BrewNoSuchFileException
+        elif res.error==0x13: # ENODEV
+            # locked system file. example: /dev.null
+            raise BrewFileLockedException
+        elif res.error != 0:
+            raise BrewStatFileException(res.error, name)
         if res.type==1 or res.type==0x86:
             # files on external media have type 0x86
             results={ 'name': name, 'type': 'file', 'size': res.size }
