@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx8100.py 4287 2007-06-12 02:33:21Z djpham $
+### $Id: com_lgvx8100.py 4395 2007-09-11 21:11:45Z djpham $
 
 """Communicate with the LG VX8100 cell phone
 
@@ -44,7 +44,7 @@ from prototypes import *
 
 
 
-class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
+class Phone(com_lg.LGNewIndexedMedia2, com_lg.LGDMPhone, com_lgvx7000.Phone):
     "Talk to the LG VX8100 cell phone"
 
     desc="LG-VX8100"
@@ -124,27 +124,28 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
 
     def __init__(self, logtarget, commport):
         com_lgvx4400.Phone.__init__(self, logtarget, commport)
+        com_lg.LGDMPhone.__init__(self)
         self.mode=self.MODENONE
 
-    def getfundamentals(self, results):
-        """Gets information fundamental to interopating with the phone and UI.
+    def get_firmware_version(self):
+        # return the firmware version
+        req=p_brew.firmwarerequest()
+        res=self.sendbrewcommand(req, self.protocolclass.firmwareresponse)
+        return res.firmware
 
-        Currently this is:
+    def setDMversion(self):
+        """Define the DM version required for this phone, default to DMv5"""
+        # not sure what the 8100 requirements are, default to v4 only
+        self._DMv5=False
 
-          - 'uniqueserial'     a unique serial number representing the phone
-          - 'groups'           the phonebook groups
-          - 'wallpaper-index'  map index numbers to names
-          - 'ringtone-index'   map index numbers to ringtone names
+    # Fundamentals:
+    #  - get_esn             - /nvm/$ESN.SYS (same as LG VX-4400)
+    #  - getgroups           - defined below
+    #  - getwallpaperindices - LGNewIndexedMedia2
+    #  - getringtoneindices  - LGNewIndexedMedia2
+    #  - DM Version          - 4 to access brew/16452/lk/mr on newer firmwares
 
-        This method is called before we read the phonebook data or before we
-        write phonebook data.
-        """
-
-        # use a hash of ESN and other stuff (being paranoid)
-        self.log("Retrieving fundamental phone information")
-        self.log("Phone serial number")
-        results['uniqueserial']=sha.new(self.getfilecontents("nvm/$SYS.ESN")).hexdigest()
-        # now read groups
+    def getgroups(self, results):
         self.log("Reading group information")
         buf=prototypes.buffer(self.getfilecontents("pim/pbgroup.dat"))
         g=self.protocolclass.pbgroups()
@@ -154,10 +155,7 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
             if len(g.groups[i].name): # sometimes have zero length names
                 groups[i]={'name': g.groups[i].name }
         results['groups']=groups
-        self.getwallpaperindices(results)
-        self.getringtoneindices(results)
-        self.log("Fundamentals retrieved")
-        return results
+        return groups
 
     def savegroups(self, data):
         groups=data['groups']
@@ -346,6 +344,8 @@ class Phone(com_lg.LGNewIndexedMedia2,com_lgvx7000.Phone):
         #sort into start order, makes it possible to see if the calendar has changed
         keys=[(x.start, k) for k,x in cal.items()]
         keys.sort()
+        # apply limiter
+        keys=keys[:self.protocolclass.NUMCALENDARENTRIES]
         # number of entries
         eventsf.numactiveitems=len(keys)
         pos=1
