@@ -84,44 +84,26 @@ class Phone(com_lg.LGUncountedIndexedMedia, com_lgvx8100.Phone):
         # return the ESN of this phone
         return self.get_brew_esn()
 
+    def setDMversion(self):
+        _fw_version=self.get_firmware_version()[-1]
+        # T83VZV04 uses DMv5
+        self._DMv5=self.my_model=='VX8300' and _fw_version>'3'
+        if self._DMv5:
+            # assume that it takes about 30 seconds for T83VZV04 to kick out of DM
+            self._timeout = 30
+
     def get_detect_data(self, res):
         com_lgvx8100.Phone.get_detect_data(self, res)
         res[self.esn_file_key]=self.get_esn()
 
     my_model='VX8300'
 
-    def getfundamentals(self, results):
-        """Gets information fundamental to interopating with the phone and UI.
-
-        Currently this is:
-
-          - 'uniqueserial'     a unique serial number representing the phone
-          - 'groups'           the phonebook groups
-          - 'wallpaper-index'  map index numbers to names
-          - 'ringtone-index'   map index numbers to ringtone names
-
-        This method is called before we read the phonebook data or before we
-        write phonebook data.
-        """
-
-        # use a hash of ESN and other stuff (being paranoid)
-        self.log("Retrieving fundamental phone information")
-        self.log("Phone serial number")
-        results['uniqueserial']=sha.new(self.get_esn()).hexdigest()
-        # now read groups
-        self.log("Reading group information")
-        buf=prototypes.buffer(self.getfilecontents("pim/pbgroup.dat"))
-        g=self.protocolclass.pbgroups()
-        g.readfrombuffer(buf, logtitle="Groups read")
-        groups={}
-        for i in range(len(g.groups)):
-            if len(g.groups[i].name): # sometimes have zero length names
-                groups[i]={'name': g.groups[i].name }
-        results['groups']=groups
-        self.getwallpaperindices(results)
-        self.getringtoneindices(results)
-        self.log("Fundamentals retrieved")
-        return results
+    # Fundamentals:
+    #  - get_esn             - Brew
+    #  - getgroups           - same as LG VX-8100
+    #  - getwallpaperindices - LGUncountedIndexedMedia
+    #  - getringtoneindices  - LGUncountedIndexedMedia
+    #  - DM Version          - 4 to access brew/16452/lk/mr on newer firmwares
 
 parentprofile=com_lgvx8100.Profile
 class Profile(parentprofile):
