@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_motov710.py 3927 2007-01-22 03:15:22Z rogerb $
+### $Id: com_motov710.py 4365 2007-08-17 21:11:59Z djpham $
 
 """Communicate with Motorola phones using AT commands"""
 # system modules
@@ -615,7 +615,8 @@ class Phone(com_moto_cdma.Phone):
         return fundamentals
 
     # Phone Detection routine
-    def _detectphone(coms, likely_ports, res, _module, _log):
+    @classmethod
+    def detectphone(_, coms, likely_ports, res, _module, _log):
         for port in likely_ports:
             _model=res.get(port, {}).get('model', None)
             if _model==_module.Profile.phone_model:
@@ -639,7 +640,6 @@ class Phone(com_moto_cdma.Phone):
                     _comm.close()
                     if __debug__:
                         raise
-    detectphone=staticmethod(_detectphone)
     
 #------------------------------------------------------------------------------
 parentprofile=com_moto_cdma.Profile
