@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_phone.py 3793 2006-12-22 04:00:51Z djpham $
+### $Id: com_phone.py 3927 2007-01-22 03:15:22Z rogerb $
 
 
 """Generic phone stuff that all models inherit from"""
@@ -34,7 +34,7 @@ except:
 modeignoreerrortypes=tuple(modeignoreerrortypes) 
 
 
-class Phone:
+class Phone(object):
     """Base class for all phones"""
     
     MODENONE="modenone"  # not talked to yet
@@ -147,7 +147,7 @@ class Phone:
     getplaylist=NotImplemented
     gett9db=NotImplemented
 
-class Profile:
+class Profile(object):
 
     BP_Calendar_Version=2
 
