@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_samsungscha950.py 4287 2007-06-12 02:33:21Z djpham $
+### $Id: com_samsungscha950.py 4365 2007-08-17 21:11:59Z djpham $
 
 """Communicate with the Samsung SCH-A950 Phone"""
 
@@ -690,8 +690,8 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
         except:
             if __debug__:
                 raise
-
-    def detectphone(coms, likely_ports, res, _module, _log):
+    @classmethod
+    def detectphone(_, coms, likely_ports, res, _module, _log):
         if not likely_ports:
             # cannot detect any likely ports
             return None
@@ -717,8 +717,6 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
                 if __debug__:
                     raise
     
-    detectphone=staticmethod(detectphone)
-
     #Phonebook stuff------------------------------------------------------------
     def _del_private_dicts(self, fundamentals):
         # delete the stuff that we created
