@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_sanyo3100.py 4086 2007-03-11 04:49:43Z sawecw $
+### $Id: com_sanyo3100.py 4365 2007-08-17 21:11:59Z djpham $
 
 """Talk to the Sanyo SCP-3100 cell phone"""
 # standard modules
@@ -93,7 +93,8 @@ class Phone(com_sanyo8300.Phone):
             if __debug__:
                 raise
 
-    def detectphone(coms, likely_ports, res, _module, _log):
+    @classmethod
+    def detectphone(_, coms, likely_ports, res, _module, _log):
         if not likely_ports:
             # cannot detect any likely ports
             return None
@@ -117,8 +118,6 @@ class Phone(com_sanyo8300.Phone):
     my_model='SCP-3100/US'
     my_manufacturer='SANYO'
 
-    detectphone=staticmethod(detectphone)
-
 parentprofile=com_sanyo8300.Profile
 class Profile(parentprofile):
 
