@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_toshibavm4050.py 3918 2007-01-19 05:15:12Z djpham $
+### $Id: com_toshibavm4050.py 4365 2007-08-17 21:11:59Z djpham $
 
 """Communicate with the toshiba CDM 8900 cell phone"""
 
@@ -437,7 +437,8 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
         res['esn']=self.comm.sendatcommand('+GSN')[0][2:] # strip off the 0x
         return
 
-    def detectphone(coms, likely_ports, res, _module, _log):
+    @classmethod
+    def detectphone(_, coms, likely_ports, res, _module, _log):
         if not likely_ports:
             # cannot detect any likely ports
             return None
@@ -462,8 +463,6 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
                 if __debug__:
                     raise
     
-    detectphone=staticmethod(detectphone)
-        
 class Profile(com_phone.Profile):
 
     protocolclass=Phone.protocolclass
