@@ -5,10 +5,11 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: sms_imexport.py 4231 2007-05-15 22:47:42Z djpham $
+### $Id: sms_imexport.py 4379 2007-08-28 03:06:58Z djpham $
 
 "Deals with SMS import/export stuff"
 # System Module
+from __future__ import with_statement
 from email.Generator import Generator
 from email.MIMEText import MIMEText
 from email.Utils import formatdate
@@ -18,6 +19,7 @@ import wx
 
 # BitPim Modules
 import bptime
+import guihelper
 import sms
 
 #------------------------------------------------------------------------------
@@ -78,12 +80,12 @@ class ExportSMSDialog(wx.Dialog):
         return hbs
 
     def OnBrowse(self, _):
-        dlg=wx.FileDialog(self, defaultFile=self.filenamectrl.GetValue(),
-                          wildcard=self._wildcards[self._format.GetValue()],
-                          style=wx.SAVE|wx.CHANGE_DIR)
-        if dlg.ShowModal()==wx.ID_OK:
-            self.filenamectrl.SetValue(dlg.GetPath())
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(wx.FileDialog(self, defaultFile=self.filenamectrl.GetValue(),
+                                                     wildcard=self._wildcards[self._format.GetValue()],
+                                                     style=wx.SAVE|wx.CHANGE_DIR),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                self.filenamectrl.SetValue(dlg.GetPath())
 
     def OnOk(self, _):
         # do export
@@ -93,10 +95,8 @@ class ExportSMSDialog(wx.Dialog):
         except:
             _fp=None
         if _fp is None:
-            dlg=wx.MessageDialog(self, 'Failed to open file ['+filename+']',
-                             'Export Error')
-            dlg.ShowModal()
-            dlg.Destroy()
+            guihelper.MessageDialog(self, 'Failed to open file ['+filename+']',
+                                    'Export Error')
             self.EndModal(wx.ID_OK)
         if self.rows_all.GetValue():
             _sms=self._data
