@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: sms_tab.py 4206 2007-04-27 20:19:34Z djpham $
+### $Id: sms_tab.py 4379 2007-08-28 03:06:58Z djpham $
 
 """
 Code to handle the SMS Tab of the BitPim main display.
@@ -15,6 +15,8 @@ save and outbox, to is not required for inbox etc.
 
 """
 # standard modules
+from __future__ import with_statement
+
 import copy
 
 # wx modules
@@ -318,34 +320,33 @@ class SMSWidget(wx.Panel, widgets.BitPimWidget):
             current_choice=guiwidgets.HistoricalDataDialog.Historical_Data
         else:
             current_choice=guiwidgets.HistoricalDataDialog.Current_Data
-        dlg=guiwidgets.HistoricalDataDialog(self,
-                                            current_choice=current_choice,
-                                            historical_date=self.historical_date,
-                                            historical_events=\
-                                            self._main_window.database.getchangescount(self._data_key))
-        if dlg.ShowModal()==wx.ID_OK:
-            self._main_window.OnBusyStart()
-            current_choice, self.historical_date=dlg.GetValue()
-            r={}
-            if current_choice==guiwidgets.HistoricalDataDialog.Current_Data:
-                self.read_only=False
-                msg_str='Current Data'
-                self.getfromfs(r)
-            else:
-                self.read_only=True
-                msg_str='Historical Data as of %s'%\
-                         str(wx.DateTimeFromTimeT(self.historical_date))
-                self.getfromfs(r, self.historical_date)
-            self.populate(r, True)
-            self.historical_data_label.SetLabel(msg_str)
-            self.list_widget.historical_data_label.SetLabel(msg_str)
-            self._main_window.OnBusyEnd()
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(guiwidgets.HistoricalDataDialog(self,
+                                                                       current_choice=current_choice,
+                                                                       historical_date=self.historical_date,
+                                                                       historical_events=\
+                                                                       self._main_window.database.getchangescount(self._data_key)),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                with guihelper.MWBusyWrapper(self._main_window):
+                    current_choice, self.historical_date=dlg.GetValue()
+                    r={}
+                    if current_choice==guiwidgets.HistoricalDataDialog.Current_Data:
+                        self.read_only=False
+                        msg_str='Current Data'
+                        self.getfromfs(r)
+                    else:
+                        self.read_only=True
+                        msg_str='Historical Data as of %s'%\
+                                 str(wx.DateTimeFromTimeT(self.historical_date))
+                        self.getfromfs(r, self.historical_date)
+                    self.populate(r, True)
+                    self.historical_data_label.SetLabel(msg_str)
+                    self.list_widget.historical_data_label.SetLabel(msg_str)
 
     def OnPrintDialog(self, mainwindow, config):
-        dlg=guiwidgets.SMSPrintDialog(self, mainwindow, config)
-        dlg.ShowModal()
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(guiwidgets.SMSPrintDialog(self, mainwindow, config),
+                                       True):
+            pass
     def CanPrint(self):
         return True
 
