@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: version.py 3991 2007-02-12 23:12:07Z djpham $
+### $Id: version.py 4315 2007-07-23 01:03:58Z djpham $
 
 """Information about BitPim version number"""
 
@@ -15,17 +15,22 @@
 # in the dollar id fields.  When freeze is run, it does those various
 # substitutions
 
-__FROZEN__="$Id: 4288 $"
+__FROZEN__="$Id: version.py 4315 2007-07-23 01:03:58Z djpham $"
 
 import os, sys
 import time
 
 name="BitPim"
-vendor="$Id: version.py 3991 2007-02-12 23:12:07Z djpham $"
+vendor="$Id: version.py 4315 2007-07-23 01:03:58Z djpham $"
 release=0  # when rereleases of the same version happen, this gets incremented
 contact="The BitPim home page is at http://www.bitpim.org.  You can post any " \
          "questions or feedback to the mailing list detailed on that page." # where users are sent to contact with feedback
 
+# user defined version
+userdefined=False
+userversion=""
+uservendor=""
+
 svnrevision=0  # we don't know
 # were we frozen?
 f=__FROZEN__.split()
@@ -39,17 +44,22 @@ if vendor[1:].startswith("Id:"):
     else:
         vendor=vendor.split()[1]
 
-_headurl="$HeadURL: https://bitpim.svn.sourceforge.net/svnroot/bitpim/releases/1.0.0/src/version.py $".split()[1]
+_headurl="$HeadURL: https://bitpim.svn.sourceforge.net/svnroot/bitpim/releases/1.0.2/src/version.py $".split()[1]
 # work out our version number
 _rp="https://bitpim.svn.sourceforge.net/svnroot/bitpim/releases/"
-if _headurl.startswith(_rp):
+
+if userdefined:
+    def isdevelopmentversion(): return True
+    version=userversion
+    vendor=uservendor
+elif _headurl.startswith(_rp):
     def isdevelopmentversion(): return False
     version=_headurl[len(_rp):].split("/")[0]
     if not vendor:
         vendor="official"
 else:
     def isdevelopmentversion(): return True
-    prefix="https://svn.sourceforge.com/svnroot/bitpim/"
+    prefix="https://bitpim.svn.sourceforge.net/svnroot/bitpim/"
     version="-".join(_headurl[len(prefix):].split("/")[:-2]) # -2 to prune off src/version.py
     del prefix
     # were we frozen?
@@ -82,13 +92,41 @@ dqverstr=".".join([`x` for x in dqver])
 
 del x
 
-
-
 url="http://www.bitpim.org"
 
 description="BitPim "+versionstring
 copyright="(C) 2003-2006 Roger Binns and others - see http://www.bitpim.org"
 
+def setversion(versionstring, vendorstring='Test'):
+    """Set the version and vendor based on user's input"""
+    # my filename
+    myfilename=os.path.splitext(__file__)[0]+".py"
+    # update with new version and vendor
+    result=[]
+    if versionstring:
+        # user specifies a version
+        _versionflg='True'
+        _version=versionstring
+        _vendor=vendorstring
+    else:
+        _versionflg='False'
+        _version=_vendor=''
+    for line in file(myfilename, "rtU"):
+        if line.startswith('userversion'):
+            line='userversion="%s"\n'%_version
+        elif line.startswith('uservendor'):
+            line='uservendor="%s"\n'%_vendor
+        elif line.startswith('userdefined'):
+            line='userdefined=%s\n'%_versionflg
+        result.append(line)
+    file(myfilename, "wt").write("".join(result))
+    # python doesn't check .pyc/.pyo files correctly so we proactively delete them
+    for ext in (".pyc", ".pyo"):
+        try:
+            os.remove(os.path.splitext(__file__)[0]+ext)
+        except OSError:
+            pass
+
 def __freeze():
     # my filename
     myfilename=os.path.splitext(__file__)[0]+".py"
